@@ -1,3 +1,11 @@
+"""
+sentry.conf.settings
+~~~~~~~~~~~~~~~~~~~~
+
+:copyright: (c) 2010 by the Sentry Team, see AUTHORS for more details.
+:license: BSD, see LICENSE for more details.
+"""
+
 from sentry.conf.defaults import *
 
 from django.conf import settings
